summaryrefslogtreecommitdiffstats
path: root/webkit/fileapi/file_system_usage_cache.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/fileapi/file_system_usage_cache.h')
-rw-r--r--webkit/fileapi/file_system_usage_cache.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/webkit/fileapi/file_system_usage_cache.h b/webkit/fileapi/file_system_usage_cache.h
index 84b2341..7c38bfb 100644
--- a/webkit/fileapi/file_system_usage_cache.h
+++ b/webkit/fileapi/file_system_usage_cache.h
@@ -12,10 +12,14 @@ namespace fileapi {
class FileSystemUsageCache {
public:
// Gets the size described in the .usage file.
// Returns less than zero if the size is not availble.
static int64 GetUsage(const FilePath& usage_file_path);
+ // Gets the dirty count in the .usage file.
+ // Returns less than zero if the .usage file is not available.
+ static int32 GetDirty(const FilePath& usage_file_path);
+
// Increments or decrements the "dirty" entry in the .usage file.
// Returns false if no .usage is available.
static bool IncrementDirty(const FilePath& usage_file_path);
@@ -12,10 +12,14 @@ namespace fileapi {
class FileSystemUsageCache {
public:
- // Gets the size described in the .usage file.
- // Returns less than zero if the size is not availble.
+ // Gets the size described in the .usage file even if dirty > 0.
+ // Returns less than zero if the .usage file is not available.
static int64 GetUsage(const FilePath& usage_file_path);